@@ -7,6 +7,8 @@ use Text::ClearSilver;
 use Text::MicroTemplate;
 use Template;
 
+use Test::More;
+
 use Benchmark qw(:all);
 use Config; printf "Perl/%vd %s\n", $^V, $Config{archname};
 
@@ -17,34 +19,54 @@ foreach my $mod(qw(Text::Xslate Text::MicroTemplate Text::ClearSilver Template))
 my $n = shift(@ARGV) || 100;
 
 my $x = Text::Xslate->new(string => <<'T' x $n);
-Hello, <:= $lang :> world!
+Hello, <:= $foo :> world!
+Hello, <:= $bar :> world!
+Hello, <:= $baz :> world!
 T
 
 my $tcs = Text::ClearSilver->new(VarEscapeMode => 'html');
-my $mt  = Text::MicroTemplate::build_mt(
-    "Hello, <?= \$_[0]->{lang} ?> world!\n" x $n
-);
+my $mt  = Text::MicroTemplate::build_mt(<<'T' x $n);
+Hello, <?= $_[0]->{foo} ?> world!
+Hello, <?= $_[0]->{bar} ?> world!
+Hello, <?= $_[0]->{baz} ?> world!
+T
+
 my $vars = {
-    lang => 'Template',
+    foo => 'FOO',
+    bar => 'BAR',
+    baz => 'BAZ',
 };
 
 $x->render($vars) eq $mt->($vars) or die "render error: ", $x->render($vars);
 
 my $tcs_tmpl = <<'T' x $n;
-Hello, <:cs var:lang :> world!
+Hello, <?cs var:foo ?> world!
+Hello, <?cs var:bar ?> world!
+Hello, <?cs var:baz ?> world!
 T
 
 my $fmt = <<'T' x $n;
 Hello, %1$s world!
+Hello, %2$s world!
+Hello, %3$s world!
 T
 
 my $tt = Template->new();
 my $tt_tmpl = <<'T' x $n;
-Hello, [% lang %] world!
+Hello, [% foo %] world!
+Hello, [% bar %] world!
+Hello, [% baz %] world!
 T
+
 {
+    plan tests => 3;
     $tt->process(\$tt_tmpl, $vars, \my $out) or die $tt->error;
-    $out eq $x->render($vars) or die "render error: ", $out;
+    is $x->render($vars), $out, 'Xslate eq TT';
+
+    $tcs->process(\$tcs_tmpl, $vars, \$out);
+    is $x->render($vars), $out, 'Xslate eq TCS';
+
+    is $x->render($vars), $mt->($vars), 'Xslate eq MT';
 }
 
 # suppose PSGI response body
@@ -68,7 +90,7 @@ cmpthese -1 => {
         return;
     },
     sprintf => sub {
-        my $body = [sprintf $fmt, $vars->{lang}];
+        my $body = [sprintf $fmt, @{$vars}{qw(foo bar baz)}];
         return;
     },
 };
